==> org-lsst-sal-camera-2.2.10-sources.jar: org/lsst/sal/camera/telemetry/Quadbox_BFRTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_BFRTelemetry extends CameraTelemetry {
  private final double protection_I;

  private final double clean_5_24V_I;

  private final double dirty_24V_I;

  private final double dirty_48V_I;

  private final double rebps_0_2_I;

  private final double rebps_3_5_I;

  private final double rebps_6_8_I;

  private final double rebps_9_12_I;

  private final double dirty_28V_I;

  private final double heater_I;

  private final double rebps_Spr_I;

  public Quadbox_BFRTelemetry(double protection_I, double clean_5_24V_I, double dirty_24V_I,
      double dirty_48V_I, double rebps_0_2_I, double rebps_3_5_I, double rebps_6_8_I,
      double rebps_9_12_I, double dirty_28V_I, double heater_I, double rebps_Spr_I) {
    this.protection_I = protection_I;
    this.clean_5_24V_I = clean_5_24V_I;
    this.dirty_24V_I = dirty_24V_I;
    this.dirty_48V_I = dirty_48V_I;
    this.rebps_0_2_I = rebps_0_2_I;
    this.rebps_3_5_I = rebps_3_5_I;
    this.rebps_6_8_I = rebps_6_8_I;
    this.rebps_9_12_I = rebps_9_12_I;
    this.dirty_28V_I = dirty_28V_I;
    this.heater_I = heater_I;
    this.rebps_Spr_I = rebps_Spr_I;
  }

  public double getProtection_I() {
    return protection_I;
  }

  public double getClean_5_24V_I() {
    return clean_5_24V_I;
  }

  public double getDirty_24V_I() {
    return dirty_24V_I;
  }

  public double getDirty_48V_I() {
    return dirty_48V_I;
  }

  public double getRebps_0_2_I() {
    return rebps_0_2_I;
  }

  public double getRebps_3_5_I() {
    return rebps_3_5_I;
  }

  public double getRebps_6_8_I() {
    return rebps_6_8_I;
  }

  public double getRebps_9_12_I() {
    return rebps_9_12_I;
  }

  public double getDirty_28V_I() {
    return dirty_28V_I;
  }

  public double getHeater_I() {
    return heater_I;
  }

  public double getRebps_Spr_I() {
    return rebps_Spr_I;
  }

  @Override
  public String toString() {
    return "Quadbox_BFRTelemetry{" + "protection_I=" + protection_I +
        ", clean_5_24V_I=" + clean_5_24V_I +", dirty_24V_I=" + dirty_24V_I +
        ", dirty_48V_I=" + dirty_48V_I +", rebps_0_2_I=" + rebps_0_2_I +
        ", rebps_3_5_I=" + rebps_3_5_I +", rebps_6_8_I=" + rebps_6_8_I +
        ", rebps_9_12_I=" + rebps_9_12_I +", dirty_28V_I=" + dirty_28V_I +", heater_I=" + heater_I +
        ", rebps_Spr_I=" + rebps_Spr_I +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double protection_I;

    private double clean_5_24V_I;

    private double dirty_24V_I;

    private double dirty_48V_I;

    private double rebps_0_2_I;

    private double rebps_3_5_I;

    private double rebps_6_8_I;

    private double rebps_9_12_I;

    private double dirty_28V_I;

    private double heater_I;

    private double rebps_Spr_I;

    private Builder() {
    }

    public Builder protection_I(double protection_I) {
      this.protection_I = protection_I;
      return this;
    }

    public Builder clean_5_24V_I(double clean_5_24V_I) {
      this.clean_5_24V_I = clean_5_24V_I;
      return this;
    }

    public Builder dirty_24V_I(double dirty_24V_I) {
      this.dirty_24V_I = dirty_24V_I;
      return this;
    }

    public Builder dirty_48V_I(double dirty_48V_I) {
      this.dirty_48V_I = dirty_48V_I;
      return this;
    }

    public Builder rebps_0_2_I(double rebps_0_2_I) {
      this.rebps_0_2_I = rebps_0_2_I;
      return this;
    }

    public Builder rebps_3_5_I(double rebps_3_5_I) {
      this.rebps_3_5_I = rebps_3_5_I;
      return this;
    }

    public Builder rebps_6_8_I(double rebps_6_8_I) {
      this.rebps_6_8_I = rebps_6_8_I;
      return this;
    }

    public Builder rebps_9_12_I(double rebps_9_12_I) {
      this.rebps_9_12_I = rebps_9_12_I;
      return this;
    }

    public Builder dirty_28V_I(double dirty_28V_I) {
      this.dirty_28V_I = dirty_28V_I;
      return this;
    }

    public Builder heater_I(double heater_I) {
      this.heater_I = heater_I;
      return this;
    }

    public Builder rebps_Spr_I(double rebps_Spr_I) {
      this.rebps_Spr_I = rebps_Spr_I;
      return this;
    }

    public Quadbox_BFRTelemetry build() {
      return new Quadbox_BFRTelemetry(protection_I, clean_5_24V_I, dirty_24V_I, dirty_48V_I, rebps_0_2_I, rebps_3_5_I, rebps_6_8_I, rebps_9_12_I, dirty_28V_I, heater_I, rebps_Spr_I);
    }
  }
}

==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/telemetry/Quadbox_BFRTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_BFRTelemetry extends CameraTelemetry {
  private final double clean_5_24V_I;

  private final double dirty_24V_I;

  private final double dirty_28V_I;

  private final double dirty_48V_I;

  private final double heater_I;

  private final double protection_I;

  private final double rebps_0_2_I;

  private final double rebps_3_5_I;

  private final double rebps_6_8_I;

  private final double rebps_9_12_I;

  private final double rebps_Spr_I;

  public Quadbox_BFRTelemetry(double clean_5_24V_I, double dirty_24V_I, double dirty_28V_I,
      double dirty_48V_I, double heater_I, double protection_I, double rebps_0_2_I,
      double rebps_3_5_I, double rebps_6_8_I, double rebps_9_12_I, double rebps_Spr_I) {
    this.clean_5_24V_I = clean_5_24V_I;
    this.dirty_24V_I = dirty_24V_I;
    this.dirty_28V_I = dirty_28V_I;
    this.dirty_48V_I = dirty_48V_I;
    this.heater_I = heater_I;
    this.protection_I = protection_I;
    this.rebps_0_2_I = rebps_0_2_I;
    this.rebps_3_5_I = rebps_3_5_I;
    this.rebps_6_8_I = rebps_6_8_I;
    this.rebps_9_12_I = rebps_9_12_I;
    this.rebps_Spr_I = rebps_Spr_I;
  }

  public double getClean_5_24V_I() {
    return clean_5_24V_I;
  }

  public double getDirty_24V_I() {
    return dirty_24V_I;
  }

  public double getDirty_28V_I() {
    return dirty_28V_I;
  }

  public double getDirty_48V_I() {
    return dirty_48V_I;
  }

  public double getHeater_I() {
    return heater_I;
  }

  public double getProtection_I() {
    return protection_I;
  }

  public double getRebps_0_2_I() {
    return rebps_0_2_I;
  }

  public double getRebps_3_5_I() {
    return rebps_3_5_I;
  }

  public double getRebps_6_8_I() {
    return rebps_6_8_I;
  }

  public double getRebps_9_12_I() {
    return rebps_9_12_I;
  }

  public double getRebps_Spr_I() {
    return rebps_Spr_I;
  }

  @Override
  public String toString() {
    return "Quadbox_BFRTelemetry{" + "clean_5_24V_I=" + clean_5_24V_I +
        ", dirty_24V_I=" + dirty_24V_I +", dirty_28V_I=" + dirty_28V_I +
        ", dirty_48V_I=" + dirty_48V_I +", heater_I=" + heater_I +", protection_I=" + protection_I +
        ", rebps_0_2_I=" + rebps_0_2_I +", rebps_3_5_I=" + rebps_3_5_I +
        ", rebps_6_8_I=" + rebps_6_8_I +", rebps_9_12_I=" + rebps_9_12_I +
        ", rebps_Spr_I=" + rebps_Spr_I +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double clean_5_24V_I;

    private double dirty_24V_I;

    private double dirty_28V_I;

    private double dirty_48V_I;

    private double heater_I;

    private double protection_I;

    private double rebps_0_2_I;

    private double rebps_3_5_I;

    private double rebps_6_8_I;

    private double rebps_9_12_I;

    private double rebps_Spr_I;

    private Builder() {
    }

    public Builder clean_5_24V_I(double clean_5_24V_I) {
      this.clean_5_24V_I = clean_5_24V_I;
      return this;
    }

    public Builder dirty_24V_I(double dirty_24V_I) {
      this.dirty_24V_I = dirty_24V_I;
      return this;
    }

    public Builder dirty_28V_I(double dirty_28V_I) {
      this.dirty_28V_I = dirty_28V_I;
      return this;
    }

    public Builder dirty_48V_I(double dirty_48V_I) {
      this.dirty_48V_I = dirty_48V_I;
      return this;
    }

    public Builder heater_I(double heater_I) {
      this.heater_I = heater_I;
      return this;
    }

    public Builder protection_I(double protection_I) {
      this.protection_I = protection_I;
      return this;
    }

    public Builder rebps_0_2_I(double rebps_0_2_I) {
      this.rebps_0_2_I = rebps_0_2_I;
      return this;
    }

    public Builder rebps_3_5_I(double rebps_3_5_I) {
      this.rebps_3_5_I = rebps_3_5_I;
      return this;
    }

    public Builder rebps_6_8_I(double rebps_6_8_I) {
      this.rebps_6_8_I = rebps_6_8_I;
      return this;
    }

    public Builder rebps_9_12_I(double rebps_9_12_I) {
      this.rebps_9_12_I = rebps_9_12_I;
      return this;
    }

    public Builder rebps_Spr_I(double rebps_Spr_I) {
      this.rebps_Spr_I = rebps_Spr_I;
      return this;
    }

    public Quadbox_BFRTelemetry build() {
      return new Quadbox_BFRTelemetry(clean_5_24V_I, dirty_24V_I, dirty_28V_I, dirty_48V_I, heater_I, protection_I, rebps_0_2_I, rebps_3_5_I, rebps_6_8_I, rebps_9_12_I, rebps_Spr_I);
    }
  }
}
